@@ -65,7 +65,7 @@ extern mod_rivet_globals* module_globals;
 if (source == VAR_SRC_QUERYSTRING) { j = nargs; } \
 else if (source == VAR_SRC_POST) { i = nargs; }
 
-/* 
+/*
  * -- TclWeb_NewRequestObject
  *
  *
@@ -98,7 +98,7 @@ TclWeb_NewRequestObject (apr_pool_t *p)
  *  TclWebRequest* req:     a pointer to a TclWebRequest object to be intialized
  *  Tcl_Interp*    interp:  current Tcl_Interp object serving the request
  *  void*          arg:     generic pointer. Current implementation passes the
- *                          request_rec object pointer 
+ *                          request_rec object pointer
  *
  */
 
@@ -126,11 +126,11 @@ TclWeb_InitRequest(rivet_thread_private* private, Tcl_Interp *interp)
 
     if (((private->ctype==RIVET_TEMPLATE) && (content_type_len > strlen(RIVET_TEMPLATE_CTYPE))) || \
         ((private->ctype==RIVET_TCLFILE) && (content_type_len > strlen(RIVET_TCLFILE_CTYPE)))) {
-        
+
         char* charset;
 
         /* we parse the content type: we are after a 'charset' parameter definition */
-        
+
         charset = strstr(r->content_type,"charset");
         if (charset != NULL) {
             charset = apr_pstrdup(r->pool,charset);
@@ -149,7 +149,7 @@ INLINE int
 TclWeb_SendHeaders(TclWebRequest *req)
 {
     //TODO: fix ap_send_http_header
-    
+
     ap_send_http_header(req->req);
 
     return TCL_OK;
@@ -167,7 +167,7 @@ TclWeb_StopSending(TclWebRequest *req)
 int
 TclWeb_SetHeaderType(char *header, TclWebRequest *req)
 {
-    
+
     if (req->headers_set)
         return TCL_ERROR;
 
@@ -193,12 +193,12 @@ TclWeb_PrintHeaders(TclWebRequest *req)
     {
         TclWeb_SetHeaderType(DEFAULT_HEADER_TYPE, req);
     }
-    
+
     /*
      * seems that ap_send_http_header is redefined to ; in Apache2.2
      * ap_send_http_header(req->req);
      */
-    
+
     TclWeb_SendHeaders(req);
 
     req->headers_printed = 1;
@@ -207,7 +207,7 @@ TclWeb_PrintHeaders(TclWebRequest *req)
 
 /* Print nice HTML formatted errors */
 int
-TclWeb_PrintError(CONST84 char *errstr, int htmlflag, TclWebRequest *req)
+TclWeb_PrintError(CONST86 char *errstr, int htmlflag, TclWebRequest *req)
 {
     TclWeb_SetHeaderType(DEFAULT_HEADER_TYPE, req);
     TclWeb_PrintHeaders(req);
@@ -245,11 +245,11 @@ TclWeb_HeaderSet(char *header, char *val, TclWebRequest *req)
  *    headers
  *  - it returns nothing since it's a wrapper around an APR call
  *    that doesn't return anything
- * 
- *  -- TclWeb_OutputHeaderGet: reads from the output headers and 
+ *
+ *  -- TclWeb_OutputHeaderGet: reads from the output headers and
  *  returns the value associated to a key. If the key is not
  *  existing it returns NULL
- *  
+ *
  */
 
 INLINE void
@@ -461,11 +461,11 @@ TclWeb_VarNumber(Tcl_Obj *result, int source, TclWebRequest *req)
 
 /* Environment variables. Include variables handling */
 
-/* These 2 array must be aligned and a one-to-one correspondence preserved 
+/* These 2 array must be aligned and a one-to-one correspondence preserved
  * The enum include_vars_idx *must* be terminated by 'invalid_env_var'
- * Adding a new env variable requires 
+ * Adding a new env variable requires
  *    + the name of the variable be listed in include_env_vars
- *    + a new value in the enumerator include_vars_idx must be added in the 
+ *    + a new value in the enumerator include_vars_idx must be added in the
  *      corresponding position
  *    + the switch construct in function TclWeb_SelectEnvIncludeVar must
  *      be expanded to handle the new case identified by the new enumerator value
@@ -483,11 +483,11 @@ enum include_vars_idx {
     invalid_env_var
 };
 
-/*  -- TclWeb_SelectEnvIncludeVar 
+/*  -- TclWeb_SelectEnvIncludeVar
  *
  *  Depending on the value idx of the enumerator a method is selected
  *  to return a string of a specific environment variable methods
- *  Adding new environment variables need new cases of the switch 
+ *  Adding new environment variables need new cases of the switch
  *  construct to be added, provided the data can be obtained from
  *  the rivet_thread_private structure
  *
@@ -501,7 +501,7 @@ enum include_vars_idx {
  *      A character string pointer to the value of the environment variable or
  *      NULL if the enumerator value idx was invalid or resolving the environment
  *      variable was impossible
- * 
+ *
  */
 
 static char*
@@ -509,12 +509,12 @@ TclWeb_SelectEnvIncludeVar (rivet_thread_private* private,int idx)
 {
     switch (idx)
     {
-        case date_local: 
+        case date_local:
         {
             apr_pool_t* pool = private->req->req->pool;
             apr_time_t date = private->req->req->request_time;
 
-            return ap_ht_time(pool,date,DEFAULT_TIME_FORMAT,0); 
+            return ap_ht_time(pool,date,DEFAULT_TIME_FORMAT,0);
         }
         case date_gmt:
         {
@@ -592,13 +592,13 @@ TclWeb_SelectEnvIncludeVar (rivet_thread_private* private,int idx)
 
 /*
  * -- TclWeb_InitEnvVars
- * 
+ *
  * Load the CGI and environment variables into the request_rec environment structure
- * Variables belong to 3 cathegories 
+ * Variables belong to 3 cathegories
  *
  *   + common variables (ap_add_common_vars)
  *   + CGI variables (ad_cgi_vars)
- *   + a miscellaneous set of variables 
+ *   + a miscellaneous set of variables
  *     listed in the array include_env_vars
  *
  * Each cathegory is controlled by flags in order to reduce the overhead of getting them
@@ -633,7 +633,7 @@ TclWeb_InitEnvVars (rivet_thread_private* private)
 
     if (!ENV_VARS_LOADED(req->environment_set))
     {
-        apr_table_t   *table;  
+        apr_table_t   *table;
         int            idx;
 
         table = req->req->subprocess_env;
@@ -656,7 +656,7 @@ TclWeb_InitEnvVars (rivet_thread_private* private)
  *    a character string pointer to the environment variable value or
  *    NULL if the environment variable name in invalid or the variable
  *    could not be resolved
- *      
+ *
  */
 
 static char*
@@ -709,7 +709,7 @@ TclWeb_GetEnvVars(Tcl_Obj *envvar,rivet_thread_private* private)
          * Default behavior (creation in the ::request namespace)
          * is now more consistently constrained by fully qualifying
          * the default array names (see rivetCore.c). This should fix
-         * Bug #48963 
+         * Bug #48963
          */
 
         Tcl_ObjSetVar2(req->interp, envvar, key, val, 0);
@@ -837,7 +837,7 @@ int TclWeb_UploadChannel(char *varname, TclWebRequest *req)
         result = Tcl_NewObj();
         Tcl_SetStringObj(result, Tcl_GetChannelName(chan), -1);
         Tcl_SetObjResult(req->interp, result);
-        
+
         return TCL_OK;
     }
 }
@@ -888,14 +888,14 @@ int TclWeb_UploadData(char *varname, TclWebRequest *req)
     if (rsc->upload_files_to_var)
     {
         Tcl_Channel chan;
-        
+
         chan = Tcl_OpenFileChannel (req->interp, req->upload->tempname, "r", 0);
         if (chan == NULL) {
             char* tcl_error_msg;
             int error_number = Tcl_GetErrno();
 
             Tcl_AddErrorInfo(req->interp,"Error opening channel to uploaded data");
-            tcl_error_msg = apr_psprintf(req->req->pool,"Error setting channel option '%s': %s", 
+            tcl_error_msg = apr_psprintf(req->req->pool,"Error setting channel option '%s': %s",
                                                         Tcl_ErrnoId(), Tcl_ErrnoMsg(error_number));
             Tcl_AddErrorInfo(req->interp,tcl_error_msg);
             return TCL_ERROR;
@@ -904,7 +904,7 @@ int TclWeb_UploadData(char *varname, TclWebRequest *req)
             char* tcl_error_msg;
             int error_number = Tcl_GetErrno();
 
-            tcl_error_msg = apr_psprintf(req->req->pool,"Error setting channel option '%s': %s", 
+            tcl_error_msg = apr_psprintf(req->req->pool,"Error setting channel option '%s': %s",
                                                         Tcl_ErrnoId(), Tcl_ErrnoMsg(error_number));
             Tcl_AddErrorInfo(req->interp,tcl_error_msg);
             return TCL_ERROR;
@@ -913,7 +913,7 @@ int TclWeb_UploadData(char *varname, TclWebRequest *req)
             char* tcl_error_msg;
             int error_number = Tcl_GetErrno();
 
-            tcl_error_msg = apr_psprintf(req->req->pool,"Error setting channel option '%s': %s", 
+            tcl_error_msg = apr_psprintf(req->req->pool,"Error setting channel option '%s': %s",
                                                         Tcl_ErrnoId(), Tcl_ErrnoMsg(error_number));
             Tcl_AddErrorInfo(req->interp,tcl_error_msg);
             return TCL_ERROR;
@@ -925,14 +925,14 @@ int TclWeb_UploadData(char *varname, TclWebRequest *req)
         if (Tcl_Close(req->interp, chan) == TCL_ERROR) {
             return TCL_ERROR;
         }
-        
+
         Tcl_SetObjResult(req->interp, result);
     } else {
         Tcl_AppendResult(req->interp,
                  "RivetServerConf UploadFilesToVar is not set", NULL);
         return TCL_ERROR;
     }
-    
+
     return TCL_OK;
 }
 
@@ -1079,7 +1079,7 @@ TclWeb_GetVirtualFile(TclWebRequest *req, char *virtualname)
  */
 
 char *
-TclWeb_GetRawPost ( TclWebRequest *req )
+TclWeb_GetRawPost ( TclWebRequest *req, int *len )
 {
-    return ApacheRequest_get_raw_post(req->apachereq);
+    return ApacheRequest_get_raw_post(req->apachereq, len);
 }
