@@ -63,7 +63,7 @@
 #define COOKIES_ARRAY_NAME "cookies"
 
 extern module rivet_module;
-extern char* TclWeb_GetRawPost (TclWebRequest *req);
+extern char* TclWeb_GetRawPost (TclWebRequest *req, int *len);
 extern mod_rivet_globals* module_globals;
 extern apr_threadkey_t*  rivet_thread_key;
 
@@ -77,7 +77,7 @@ extern apr_threadkey_t*  rivet_thread_key;
 /*
  * -- Rivet_NoRequestRec
  *
- * Adds standard error information to the interpreter. This procedure makes 
+ * Adds standard error information to the interpreter. This procedure makes
  * sense only when called by C functions implementing Tcl commands that
  * are meaningful only if a valid requiest_rec object is defined. These
  * procedures must return TCL_ERROR right away after Rivet_NoRequestRecord
@@ -157,9 +157,9 @@ TCL_CMD_HEADER( Rivet_MakeURL )
 
             if (script_name_l > 0)
             {
-                // script name may have the form a directory path (and mod_rewrite 
+                // script name may have the form a directory path (and mod_rewrite
                 // could have mapped it to a .tcl or .rvt script)
-                
+
                 if (script_name[script_name_l-1] == '/')
                 {
                     url_target_name = apr_pstrcat(private->req->req->pool,script_name,url_target_name,NULL);
@@ -176,7 +176,7 @@ TCL_CMD_HEADER( Rivet_MakeURL )
         }
     }
 
-    result = Tcl_NewObj();   
+    result = Tcl_NewObj();
     TclWeb_MakeURL(result, url_target_name, private->req);
     Tcl_SetObjResult(interp, result);
 
@@ -247,7 +247,7 @@ TCL_CMD_HEADER( Rivet_Parse )
             if (Rivet_Parser(outbuf, script) == 0)
             {
                 Tcl_AppendToObj(outbuf, "\"\n", 2);
-            } 
+            }
 
             Tcl_AppendToObj(outbuf,"\n",-1);
 
@@ -257,7 +257,7 @@ TCL_CMD_HEADER( Rivet_Parse )
             return res;
             //return Rivet_ParseExecString(private, objv[2]);
 
-        } else { 
+        } else {
 
             Tcl_WrongNumArgs( interp, 1, objv, "?-virtual? filename | -string template_string" );
             return TCL_ERROR;
@@ -283,7 +283,7 @@ TCL_CMD_HEADER( Rivet_Parse )
 
     /* */
 
-    cache_key = 
+    cache_key =
         RivetCache_MakeKey( private->pool,filename,
                             finfo_b.ctime,finfo_b.mtime,
                             IS_USER_CONF(private->running_conf),0);
@@ -325,10 +325,10 @@ TCL_CMD_HEADER( Rivet_Parse )
         result = Tcl_EvalObjEx(interp,script,0);
         Tcl_DecrRefCount(script);
         return result;
-               
+
     } else {
         script = RivetCache_FetchScript(entry);
-        return Tcl_EvalObjEx(interp,script,0); 
+        return Tcl_EvalObjEx(interp,script,0);
     }
 
 }
@@ -486,7 +486,7 @@ TCL_CMD_HEADER( Rivet_Headers )
             return TCL_ERROR;
         }
 
-        header_value = TclWeb_OutputHeaderGet(Tcl_GetString(objv[2]),private->req); 
+        header_value = TclWeb_OutputHeaderGet(Tcl_GetString(objv[2]),private->req);
 
         Tcl_SetObjResult(interp,Tcl_NewStringObj(header_value ? header_value : "",-1));
     }
@@ -655,7 +655,7 @@ TCL_CMD_HEADER ( Rivet_LoadHeaders )
 TCL_CMD_HEADER ( Rivet_Var )
 {
     rivet_thread_private*   private;
-    const char*             cmd; 
+    const char*             cmd;
     char*                   command;
     Tcl_Obj*                result = NULL;
     int                     source;
@@ -677,7 +677,7 @@ TCL_CMD_HEADER ( Rivet_Var )
     /* determine if var_qs, var_post or var was called */
 
     /* first of all we have to skip the namespace string at the beginning of the command:
-     * 
+     *
      * This fragment of code is taken from tcl 8.6.6 (tclNamesp.c) and it's part of the
      * function implementing Tcl "namespace tail", as such it should be authoritative
      * regarding the stripping of the namespace from a FQ command name
@@ -686,7 +686,7 @@ TCL_CMD_HEADER ( Rivet_Var )
     for (p = cmd;  *p != '\0';  p++) {
 	    /* empty body */
     }
-    
+
     while (--p > cmd) {
         if ((*p == ':') && (*(p-1) == ':')) {
             p++;			/* Just after the last "::" */
@@ -808,9 +808,9 @@ TCL_CMD_HEADER ( Rivet_Var )
                     return TCL_ERROR;
                 }
 
-                for (; !done ; Tcl_DictObjNext(&search, &key, &value, &done)) 
+                for (; !done ; Tcl_DictObjNext(&search, &key, &value, &done))
                 {
-                    if (Tcl_DictObjGet(interp,result,key,&valuePtr) == TCL_OK) 
+                    if (Tcl_DictObjGet(interp,result,key,&valuePtr) == TCL_OK)
                     {
                         if (valuePtr == NULL)
                         {
@@ -886,7 +886,7 @@ TCL_CMD_HEADER( Rivet_ApacheTable )
     apr_table_t *table = NULL;
     int subcommandindex;
 
-    static CONST84 char *SubCommand[] = {
+    static CONST86 char *SubCommand[] = {
         "get",
         "set",
         "exists",
@@ -907,7 +907,7 @@ TCL_CMD_HEADER( Rivet_ApacheTable )
         SUB_CLEAR
     };
 
-    static CONST84 char *tableNames[] = {
+    static CONST86 char *tableNames[] = {
         "notes",
         "headers_in",
         "headers_out",
@@ -1132,7 +1132,7 @@ TCL_CMD_HEADER( Rivet_Upload )
      * of an upload
      */
 
-    static CONST84 char *SubCommand[] = {
+    static CONST86 char *SubCommand[] = {
         "channel",
         "save",
         "data",
@@ -1157,7 +1157,7 @@ TCL_CMD_HEADER( Rivet_Upload )
         NAMES
     };
 
-    static CONST84 int cmds_objc[] = { 3,4,3,3,3,3,3,3,2 };
+    static CONST86 int cmds_objc[] = { 3,4,3,3,3,3,3,3,2 };
     int expected_objc;
 
     rivet_thread_private* private;
@@ -1209,7 +1209,7 @@ TCL_CMD_HEADER( Rivet_Upload )
             Tcl_SetIntObj(result,upload_prepared);
             Tcl_SetObjResult(interp, result);
             return TCL_OK;
-                
+
         }
 
         if (tcl_status != TCL_OK)
@@ -1274,18 +1274,19 @@ TCL_CMD_HEADER( Rivet_Upload )
 TCL_CMD_HEADER ( Rivet_RawPost )
 {
     char*                   data;
+    int                     length;
     Tcl_Obj*                retval;
     rivet_thread_private*   private;
 
     THREAD_PRIVATE_DATA(private)
     CHECK_REQUEST_REC(private,"::rivet::raw_post")
 
-    data = TclWeb_GetRawPost(private->req);
+    data = TclWeb_GetRawPost(private->req, &length);
 
     if (!data) {
         data = "";
     }
-    retval = Tcl_NewStringObj(data, -1);
+    retval = Tcl_NewByteArrayObj((const unsigned char *)data, length);
     Tcl_SetObjResult(interp, retval);
     return TCL_OK;
 }
@@ -1358,7 +1359,7 @@ TCL_CMD_HEADER( Rivet_AbortPageCmd )
     if (objc == 2)
     {
         char* cmd_arg = Tcl_GetStringFromObj(objv[1],NULL);
-        
+
         if (strcmp(cmd_arg,"-aborting") == 0)
         {
             Tcl_SetObjResult (interp,Tcl_NewBooleanObj(private->page_aborting));
@@ -1370,12 +1371,12 @@ TCL_CMD_HEADER( Rivet_AbortPageCmd )
             Tcl_SetObjResult (interp,Tcl_NewBooleanObj(private->thread_exit));
             return TCL_OK;
         }
- 
-    /* 
+
+    /*
      * we assume abort_code to be null, as abort_page shouldn't run twice while
-     * processing the same request 
+     * processing the same request
      */
-       
+
         if (private->abort_code == NULL)
         {
             private->abort_code = objv[1];
@@ -1383,7 +1384,7 @@ TCL_CMD_HEADER( Rivet_AbortPageCmd )
         }
     }
 
-    /* 
+    /*
      * If page_aborting is true then this is the second call to abort_page
      * processing the same request: we ignore it and return a normal
      * completion code
@@ -1396,7 +1397,7 @@ TCL_CMD_HEADER( Rivet_AbortPageCmd )
 
     /* this is the first (and supposedly unique) abort_page call during this request */
 
-    /* we eleveta the page_aborting flag to the actual flag controlling the page abort execution. 
+    /* we eleveta the page_aborting flag to the actual flag controlling the page abort execution.
      * We still return the RIVET and ABORTPAGE_CODE, but internally
      * its page_aborting that will drive the code execution after abort_page
      */
@@ -1410,9 +1411,9 @@ TCL_CMD_HEADER( Rivet_AbortPageCmd )
 
 /*
  *-----------------------------------------------------------------------------
- * Rivet_AbortCodeCmd -- 
+ * Rivet_AbortCodeCmd --
  *
- * Returns the abort code stored internally by passing a user defined parameter 
+ * Returns the abort code stored internally by passing a user defined parameter
  * to the command 'abort_page'.
  *
  *
@@ -1421,7 +1422,7 @@ TCL_CMD_HEADER( Rivet_AbortPageCmd )
 TCL_CMD_HEADER( Rivet_AbortCodeCmd )
 {
     rivet_thread_private*   private;
-    
+
     THREAD_PRIVATE_DATA(private)
 
     if (private->abort_code != NULL)
@@ -1454,7 +1455,7 @@ TCL_CMD_HEADER( Rivet_EnvCmd )
     char*                   key;
     char*                   val;
     rivet_thread_private*   private;
-    
+
     THREAD_PRIVATE_DATA(private)
     CHECK_REQUEST_REC(private,"::rivet::env")
 
@@ -1480,14 +1481,14 @@ TCL_CMD_HEADER( Rivet_EnvCmd )
  *      as 'worker') the procedure should cause a thread to exit, not the
  *      whole process with all its threads. In this case the procedure
  *      returns an TCL_ERROR code that has to be handled in mod_rivet so that
- *      the error is ignored and the request procedure interrupted. 
- *      For a non threaded MPM (such as 'prefork') the single child process 
- *      exits thus reproducing an ordinary 'exit' command. 
+ *      the error is ignored and the request procedure interrupted.
+ *      For a non threaded MPM (such as 'prefork') the single child process
+ *      exits thus reproducing an ordinary 'exit' command.
  *
  * Result:
  *
- *      TCL_ERROR 
- * 
+ *      TCL_ERROR
+ *
  * Side Effects:
  *
  *      - non threaded MPMs: the child process exits for good
@@ -1519,13 +1520,13 @@ TCL_CMD_HEADER( Rivet_ExitCmd )
     private->page_aborting = 1;
     private->abort_code = Tcl_NewDictObj();
 
-    /* The private->abort_code ref count is decremented before 
+    /* The private->abort_code ref count is decremented before
      * request processing terminates */
 
     Tcl_IncrRefCount(private->abort_code);
 
     /*
-     * mod_rivet traps call to exit and offers a chance to handle them 
+     * mod_rivet traps call to exit and offers a chance to handle them
      * in the way we handle ::rivet::abort_page calls
      */
 
@@ -1590,7 +1591,7 @@ TCL_CMD_HEADER( Rivet_VirtualFilenameCmd )
  *
  * Rivet_Inspect --
  *
- *      Rivet configuration introspection. Command '::rivet::inspect' 
+ *      Rivet configuration introspection. Command '::rivet::inspect'
  *      returns a dictionary of configuration data:
  *
  * Results:
@@ -1602,7 +1603,7 @@ TCL_CMD_HEADER( Rivet_VirtualFilenameCmd )
 TCL_CMD_HEADER( Rivet_InspectCmd )
 {
     rivet_thread_private*   private;
-    rivet_server_conf*      rsc; 
+    rivet_server_conf*      rsc;
     int                     status = TCL_OK;
 
     THREAD_PRIVATE_DATA(private)
@@ -1612,7 +1613,7 @@ TCL_CMD_HEADER( Rivet_InspectCmd )
         Tcl_Obj* dictObj;
 
         CHECK_REQUEST_REC(private,"::rivet::inspect")
-        rsc = Rivet_GetConf(private->r); 
+        rsc = Rivet_GetConf(private->r);
         dictObj = Rivet_BuildConfDictionary(interp,rsc);
         if (dictObj != NULL) {
             Tcl_IncrRefCount(dictObj);
@@ -1646,7 +1647,7 @@ TCL_CMD_HEADER( Rivet_InspectCmd )
 
             cmd = Tcl_NewStringObj("info script",-1);
 
-            Tcl_IncrRefCount(cmd); 
+            Tcl_IncrRefCount(cmd);
             status = Tcl_EvalObjEx(interp,cmd,TCL_EVAL_DIRECT);
             Tcl_DecrRefCount(cmd);
 
@@ -1654,12 +1655,12 @@ TCL_CMD_HEADER( Rivet_InspectCmd )
         else if (STRNEQU(cmd_arg,"-all"))
         {
             Tcl_Obj* dictObj;
-            
+
             CHECK_REQUEST_REC(private,"::rivet::inspect -all")
-            rsc = Rivet_GetConf(private->r); 
+            rsc = Rivet_GetConf(private->r);
             dictObj = Rivet_CurrentConfDict(interp,rsc);
             Tcl_IncrRefCount(dictObj);
-            Tcl_SetObjResult(interp,dictObj);            
+            Tcl_SetObjResult(interp,dictObj);
             Tcl_DecrRefCount(dictObj);
 
         }
@@ -1673,7 +1674,7 @@ TCL_CMD_HEADER( Rivet_InspectCmd )
             } else {
 
                 if (private->r == NULL) {
-                    srec = module_globals->server; 
+                    srec = module_globals->server;
                 } else {
                     srec = private->r->server;
                 }
@@ -1684,14 +1685,14 @@ TCL_CMD_HEADER( Rivet_InspectCmd )
 
             dictObj = Rivet_CurrentServerRec(interp,srec);
             Tcl_IncrRefCount(dictObj);
-            Tcl_SetObjResult(interp,dictObj);            
+            Tcl_SetObjResult(interp,dictObj);
             Tcl_DecrRefCount(dictObj);
 
         }
         else if (STRNEQU(cmd_arg,"exit"))
         {
             Tcl_Obj* exit_flag;
-            
+
             CHECK_REQUEST_REC(private,"::rivet::inspect")
             /* thread exit status flag */
             exit_flag = Tcl_NewIntObj(private->thread_exit);
@@ -1712,7 +1713,7 @@ TCL_CMD_HEADER( Rivet_InspectCmd )
                 if (private->r == NULL) {
                     rsc = private->running_conf;
                 } else {
-                    rsc = Rivet_GetConf(private->r); 
+                    rsc = Rivet_GetConf(private->r);
                 }
 
             }
@@ -1739,7 +1740,7 @@ TCL_CMD_HEADER( Rivet_InspectCmd )
 
         Tcl_DecrRefCount(par_name);
     }
-    else 
+    else
     {
         Tcl_WrongNumArgs( interp, 1, objv, "?server | dir | user? ?parameter name?" );
         status = TCL_ERROR;
@@ -1756,8 +1757,8 @@ TCL_CMD_HEADER( Rivet_InspectCmd )
  *
  *      log_error priority message
  *
- *        priority can be one of "emerg", "alert", "crit", "err",
- *            "warning", "notice", "info", "debug"
+ *        priority can be one of "emerg","alert","crit","err",
+ *                               "warning","notice","info","debug"
  *
  * Results:
  *      A message is logged to the Apache error log.
@@ -1765,16 +1766,16 @@ TCL_CMD_HEADER( Rivet_InspectCmd )
  *-----------------------------------------------------------------------------
  */
 
-TCL_CMD_HEADER( Rivet_LogErrorCmd )
+TCL_CMD_HEADER(Rivet_LogErrorCmd)
 {
     char *message = NULL;
 
     server_rec *serverRec;
 
     int loglevelindex;
-    int  apLogLevel = 0;
+    int apLogLevel = 0;
 
-    static CONST84 char *logLevel[] = {
+    static CONST86 char *logLevel[] = {
         "emerg",
         "alert",
         "crit",
@@ -1852,9 +1853,16 @@ TCL_CMD_HEADER( Rivet_LogErrorCmd )
      * root server name stored in the module_globals
      */
 
-    serverRec = ((private == NULL) || (private->r == NULL)) ? module_globals->server : private->r->server;
-
-    ap_log_error (APLOG_MARK, apLogLevel, 0, serverRec, "%s", message);
+    if ((private == NULL) || (private->r == NULL))
+    {
+        rivet_interp_globals* globals = Tcl_GetAssocData(interp, "rivet", NULL);
+        serverRec = globals->server;
+    }
+    else
+    {
+        serverRec = private->r->server;
+    }
+    ap_log_error (APLOG_MARK,apLogLevel,0,serverRec,"%s",message);
     return TCL_OK;
 }
 
@@ -1868,7 +1876,7 @@ TCL_CMD_HEADER( Rivet_LogErrorCmd )
  *      Calls the panic routine.
  *
  * Results:
- *      Always returns TCL_OK. 
+ *      Always returns TCL_OK.
  *
  * Side effects:
  *      May exit application.
@@ -1924,7 +1932,7 @@ TCL_CMD_HEADER( Rivet_UrlScript )
     Tcl_HashEntry*       entry  = NULL;
     Tcl_Obj*             script = NULL;
     int                  result;
-    unsigned int         user_conf; 
+    unsigned int         user_conf;
     time_t               ctime;
     time_t               mtime;
 
@@ -1942,7 +1950,7 @@ TCL_CMD_HEADER( Rivet_UrlScript )
     if (entry == NULL)
     {
         Tcl_Interp*     interp;
-        
+
         interp = rivet_interp->interp;
 
         script = Tcl_NewObj();
@@ -1974,11 +1982,11 @@ TCL_CMD_HEADER( Rivet_UrlScript )
                 Tcl_HashEntry* entry;
 
                 entry = RivetCache_CreateEntry (rivet_interp,cache_key,&isNew);
-    
+
                 /* Sanity check: we are here for this reason */
 
                 ap_assert(isNew == 1);
-            
+
                 /* we proceed storing the script in the cache */
 
                 RivetCache_StoreScript(rivet_interp,entry,script);
@@ -2009,7 +2017,7 @@ TCL_CMD_HEADER( Rivet_UrlScript )
  * With a threaded bridge (worker and lazy) command [pid] on Unix systems return
  * the same process id when called from all threads running within that process.
  * For any debugging reason this command returns a unique thread identification
- * that can, for instance, be matched with the thread id (tid) information 
+ * that can, for instance, be matched with the thread id (tid) information
  * in the error log file.
  *
  * Arguments:
@@ -2066,7 +2074,7 @@ TCL_CMD_HEADER( Rivet_GetThreadId )
             Tcl_AddObjErrorInfo(interp,"Wrong argument: it must be -decimal | -hex", -1);
             return TCL_ERROR;
         }
-    } 
+    }
     else if (objc > 2)
     {
         Tcl_WrongNumArgs(interp,1,objv,"-decimal | -hex" );
@@ -2093,7 +2101,7 @@ TCL_CMD_HEADER( Rivet_GetThreadId )
  *      documented within the 'Rivet Internals' section of the manual
  *
  * Results:
- *      
+ *
  *      a Tcl list of the keys in the interpreter cache
  *
  * Side Effects:
@@ -2114,12 +2122,12 @@ TCL_CMD_HEADER( Rivet_CacheContent )
 
     rivet_interp = RIVET_PEEK_INTERP(private,private->running_conf);
     interp = rivet_interp->interp;
-    
+
     entry_list = Tcl_NewObj();
     Tcl_IncrRefCount(entry_list);
 
     ep = rivet_interp->cache_size - 1;
-    
+
     while ((ep >= 0) && (rivet_interp->objCacheList[ep]))
     {
         int tcl_status;
@@ -2158,7 +2166,7 @@ TCL_CMD_HEADER( Rivet_CacheContent )
 DLLEXPORT int
 Rivet_InitCore(Tcl_Interp *interp,rivet_thread_private* private)
 {
-    rivet_server_conf*      server_conf; 
+    rivet_server_conf* server_conf;
 
     RIVET_OBJ_CMD ("makeurl",Rivet_MakeURL,private);
     RIVET_OBJ_CMD ("headers",Rivet_Headers,private);
@@ -2182,7 +2190,7 @@ Rivet_InitCore(Tcl_Interp *interp,rivet_thread_private* private)
     RIVET_OBJ_CMD ("exit",Rivet_ExitCmd,private);
     RIVET_OBJ_CMD ("url_script",Rivet_UrlScript,private);
     RIVET_OBJ_CMD ("thread_id",Rivet_GetThreadId,private);
-    
+
 #ifdef RIVET_DEBUG_BUILD
     /* code compiled conditionally for debugging */
     RIVET_OBJ_CMD ("cache_content",Rivet_CacheContent,private);
